@@ -5,31 +5,27 @@ This module controls the 'Devices' tab of the Controller GUI.
 """
 
 import json
-from polychromatic.procpid import DeviceSoftwareState
-from .. import bulkapply
-from .. import common
-from .. import effects
-from .. import locales
-from .. import preferences as pref
-from .. import middleman
-from . import shared
-from ..backends._backend import Backend as Backend
-from ..qt.flowlayout import FlowLayout as QFlowLayout
-
 import os
+import shutil
 import subprocess
 import time
-import shutil
 import webbrowser
 
-from PyQt5.QtCore import Qt, QSize, QMargins, QThread
-from PyQt5.QtGui import QIcon, QPixmap, QFont
-from PyQt5.QtWidgets import QWidget, QDialogButtonBox, QGroupBox, QGridLayout, \
-                            QPushButton, QToolButton, QMessageBox, QListWidget, \
-                            QTreeWidget, QTreeWidgetItem, QLabel, QComboBox, \
-                            QSpacerItem, QSizePolicy, QSlider, QCheckBox, \
-                            QButtonGroup, QRadioButton, QDialog, QTableWidget, \
-                            QTableWidgetItem, QAction, QHBoxLayout
+from PyQt6.QtCore import QMargins, QSize, Qt, QThread
+from PyQt6.QtGui import QAction, QIcon
+from PyQt6.QtWidgets import (QAbstractItemView, QButtonGroup, QCheckBox,
+                             QComboBox, QDialog, QDialogButtonBox, QHBoxLayout,
+                             QLabel, QPushButton, QRadioButton, QSizePolicy,
+                             QSlider, QTableWidget, QTableWidgetItem,
+                             QToolButton, QTreeWidget, QTreeWidgetItem,
+                             QWidget)
+
+from polychromatic.procpid import DeviceSoftwareState
+
+from .. import bulkapply, common
+from ..backends._backend import Backend as Backend
+from ..qt.flowlayout import FlowLayout as QFlowLayout
+from . import shared
 
 # Error codes
 ERROR_NO_DEVICE = 0
@@ -80,11 +76,6 @@ class DevicesTab(shared.TabData):
         devices_branch.section = None
         tasks_branch.child(0).section = "apply-to-all"
 
-        # Backends are still initialising
-        if not self.appdata.ready:
-            self._open_loading()
-            return
-
         # Recache the device list
         self.SidebarTree.parent().show()
         device_list = self.middleman.get_devices()
@@ -94,6 +85,7 @@ class DevicesTab(shared.TabData):
         devices_branch.takeChildren()
 
         for device in device_list:
+            assert isinstance(device, Backend.DeviceItem)
             item = QTreeWidgetItem()
             item.setText(0, device.name)
             item.setIcon(0, QIcon(device.form_factor["icon"]))
@@ -101,13 +93,14 @@ class DevicesTab(shared.TabData):
             item.device_item = device
             devices_branch.addChild(item)
 
-        devices_branch.sortChildren(0, Qt.AscendingOrder)
+        devices_branch.sortChildren(0, Qt.SortOrder.AscendingOrder)
 
         # For unknown devices, check support status using local index
         device_index = json.loads(open(f"{self.paths.data_dir}/devices/openrazer.json", "r").read())
         supported_pids = device_index.keys()
 
         for device in unknown_device_list:
+            assert isinstance(device, Backend.UnknownDeviceItem)
             vidpid = f"{device.vid}:{device.pid}"
 
             if vidpid in supported_pids:
@@ -163,7 +156,7 @@ class DevicesTab(shared.TabData):
         elif item.section == "device":
             self.open_device(item.device_item)
 
-    def _get_device_summary_widget(self, device):
+    def _get_device_summary_widget(self, device: Backend.DeviceItem):
         """
         Generate the heading at the top of the page that shows the name, image
         and current state of the selected device.
@@ -278,7 +271,7 @@ class DevicesTab(shared.TabData):
 
         return self.widgets.create_summary_widget(real_image, device.name, badges, buttons)
 
-    def open_device(self, device):
+    def open_device(self, device: Backend.DeviceItem):
         """
         Show details and controls for changing the current hardware state
         of the specified device.
@@ -292,7 +285,7 @@ class DevicesTab(shared.TabData):
 
         try:
             device.refresh()
-        except Exception as e:
+        except Exception:
             # State may have changed, reload the device tab.
             # TODO: Show "device changes detected" in status bar. Needs global function.
             self.middleman.invalidate_cache()
@@ -361,14 +354,9 @@ class DevicesTab(shared.TabData):
 
                 # TODO: Button to set compatible software effects - or as "Custom" effect?
 
-                # -- Mouse Acceleration
-                # TODO: Move to middleman for all interfaces?
-                if device.form_factor == "mouse":
-                    widgets.append(self.special_controls.create_mouse_accel_control())
-
                 # -- Information about OpenRazer daemon's built-in macro feature (deprecated)
                 if device.has_macro_keys:
-                   widgets.append(self.special_controls.create_openrazer_macro_control())
+                    widgets.append(self.special_controls.create_openrazer_macro_control())
 
                 # -- Information about programmable keys
                 if device.has_programmable_keys and self.input_remapper:
@@ -406,11 +394,11 @@ class DevicesTab(shared.TabData):
         elif isinstance(option, Backend.MultipleChoiceOption):
             return self.widgets.create_row_widget(option.label, self._create_control_select(option))
 
-    def _create_control_slider(self, option):
+    def _create_control_slider(self, option: Backend.SliderOption):
         """
         Returns a list of controls that make up a slider for changing a variable option.
         """
-        slider = QSlider(Qt.Horizontal)
+        slider = QSlider(Qt.Orientation.Horizontal)
         slider.setValue(option.value)
         slider.setMinimum(option.min)
         slider.setMaximum(option.max)
@@ -419,7 +407,7 @@ class DevicesTab(shared.TabData):
         slider.setMaximumWidth(150)
 
         # BUG: Qt: Ticks don't appear with stylesheet
-        slider.setTickPosition(QSlider.TicksBelow)
+        slider.setTickPosition(QSlider.TickPosition.TicksBelow)
         slider.setTickInterval(int(option.max / 10))
 
         label = QLabel()
@@ -446,7 +434,7 @@ class DevicesTab(shared.TabData):
 
         return [slider, label]
 
-    def _create_control_toggle(self, option):
+    def _create_control_toggle(self, option: Backend.ToggleOption):
         """
         Returns a list of controls that make up a toggle for a binary choices.
         """
@@ -466,7 +454,7 @@ class DevicesTab(shared.TabData):
         checkbox.stateChanged.connect(_state_changed)
         return [checkbox]
 
-    def _create_control_select(self, option):
+    def _create_control_select(self, option: Backend.MultipleChoiceOption):
         """
         Returns a list of controls that make up a multiple choice dropdown.
         """
@@ -476,6 +464,7 @@ class DevicesTab(shared.TabData):
         combo.setIconSize(QSize(16, 16))
 
         for index, param in enumerate(params):
+            assert isinstance(param, Backend.Option.Parameter)
             combo.addItem(param.label)
             if param.icon:
                 combo.setItemIcon(combo.count() - 1, QIcon(param.icon))
@@ -495,7 +484,7 @@ class DevicesTab(shared.TabData):
         combo.currentIndexChanged.connect(_current_index_changed)
         return [combo]
 
-    def _create_effect_controls(self, zone, options):
+    def _create_effect_controls(self, zone: Backend.DeviceItem.Zone, options: list):
         """
         Return a row widget containing the specified options. These are grouped
         together and will be presented as larger buttons.
@@ -504,17 +493,19 @@ class DevicesTab(shared.TabData):
         self.btn_grps[zone] = QButtonGroup()
 
         for option in options:
+            assert isinstance(option, Backend.EffectOption)
             button = QToolButton()
             button.setText(option.label)
             button.setCheckable(True)
             button.setIconSize(QSize(40, 40))
-            button.setToolButtonStyle(Qt.ToolButtonTextUnderIcon)
+            button.setToolButtonStyle(Qt.ToolButtonStyle.ToolButtonTextUnderIcon)
             if option.icon:
                 button.setIcon(QIcon(option.icon))
             button.setMinimumHeight(70)
             button.setMinimumWidth(105)
             button.option = option
-            self.btn_grps[zone].addButton(button)
+            btn_grp: QButtonGroup = self.btn_grps[zone]
+            btn_grp.addButton(button)
 
             if option.active:
                 button.setChecked(True)
@@ -522,8 +513,8 @@ class DevicesTab(shared.TabData):
             widgets.append(button)
 
         def _clicked_effect_button(button):
-            option = button.option
-            param = self.middleman.get_default_parameter(option)
+            option: Backend.EffectOption = button.option
+            param: Backend.EffectOption.Parameter = self.middleman.get_default_parameter(option)
             self.middleman.stop_software_effect(self.current_device.serial)
 
             try:
@@ -538,14 +529,15 @@ class DevicesTab(shared.TabData):
 
             self.reload_device()
 
-        self.btn_grps[zone].buttonClicked.connect(_clicked_effect_button)
+        btn_grp: QButtonGroup = self.btn_grps[zone]
+        btn_grp.buttonClicked.connect(_clicked_effect_button)
 
         if not widgets:
             return None
 
         return self.widgets.create_row_widget(self._("Effect"), widgets, wrap=True)
 
-    def _create_effect_parameter_controls(self, device, zone, option):
+    def _create_effect_parameter_controls(self, device: Backend.DeviceItem, zone: Backend.DeviceItem.Zone, option: Backend.EffectOption):
         """
         Returns a list of row widgets that change the active effect's parameters.
         """
@@ -554,6 +546,7 @@ class DevicesTab(shared.TabData):
 
         def _clicked_param_button():
             for radio in self.btn_grps["radio_param_" + zone.zone_id]:
+                assert isinstance(radio, QRadioButton)
                 if not radio.isChecked():
                     continue
                 self.dbg.stdout(f"{device.name}: Setting parameter for '{option.uid}' to '{radio.param.data}'", self.dbg.action, 1)
@@ -639,110 +632,6 @@ class DevicesTab(shared.TabData):
                                      self._("Try restarting [OpenRazer] and Polychromatic and give it another go. If this error appears again, it might need fixing in [OpenRazer].").replace("[OpenRazer]", backend_name),
                                      details=exception)
 
-    def _open_loading(self):
-        """
-        Show a skeleton loading screen while backends finish loading.
-
-        A thread will spawn to refresh the devices tab (if open) when the
-        middleman has fully populated.
-        """
-        if self.load_thread:
-            return
-
-        # Sidebar
-        self.SidebarTree.setEnabled(False)
-        tasks_branch = self.SidebarTree.invisibleRootItem().child(0)
-        devices_branch = self.SidebarTree.invisibleRootItem().child(1)
-        tasks_branch.setHidden(True)
-
-        # Skeleton devices
-        device_icon = QIcon()
-        device_icon.addFile(common.get_icon("general", "placeholder"), mode=QIcon.Disabled)
-        skel_strings = [
-            "█████████████",
-            "████████████",
-            "█████████",
-            "███████████",
-            "███████",
-        ]
-        for i in range(0, 5):
-            skel = QTreeWidgetItem()
-            skel.setText(0, skel_strings[i])
-            skel.setIcon(0, device_icon)
-            skel.setDisabled(True)
-            devices_branch.addChild(skel)
-
-        # Skeleton summary
-        def dummy():
-            pass
-
-        buttons = []
-        indicators = [
-            {
-                "icon": common.get_icon("general", "placeholder"),
-                "label": "██████"
-            },
-            {
-                "icon": common.get_icon("general", "placeholder"),
-                "label": "███"
-            }
-        ]
-        summary = self.widgets.create_summary_widget(common.get_icon("devices", "noimage"), "████████████", indicators, buttons)
-
-        # Skeleton device controls (brightness & effect)
-        skels_text = summary.findChildren(QLabel)
-        skels_bg = []
-
-        dummy_slider = QLabel("________________________")
-        dummy_slider.setMaximumWidth(180)
-        dummy_slider.setAlignment(Qt.AlignLeft)
-        skels_bg.append(dummy_slider)
-
-        dummy_buttons = []
-        for i in range(0, 5):
-            dummy = QLabel()
-            dummy.setMinimumHeight(70)
-            dummy.setMinimumWidth(70)
-            dummy.setMaximumHeight(70)
-            dummy.setMaximumWidth(70)
-            dummy.setAlignment(Qt.AlignLeft)
-            dummy_buttons.append(dummy)
-            skels_bg.append(dummy)
-
-        row1 = self.widgets.create_row_widget("███████", [dummy_slider], wrap=True)
-        row2 = self.widgets.create_row_widget("████", dummy_buttons, wrap=True)
-
-        label1 = row1.findChild(QLabel)
-        label2 = row2.findChild(QLabel)
-
-        skels_text.append(label1)
-        skels_text.append(label2)
-
-        # Apply skeleton styling
-        for skel in skels_bg:
-            skel.setStyleSheet("QLabel { background-color: #202020; color: #202020; margin: 4px 0; }")
-        for skel in skels_text:
-            skel.setStyleSheet("QLabel { color: #202020; }")
-
-        # Append widgets
-        layout = self.Contents.layout()
-        for widget in [summary, row1, row2]:
-            layout.addWidget(widget)
-        layout.addStretch()
-
-        class WaitForBackendThread(QThread):
-            @staticmethod
-            def run():
-                while not self.appdata.ready:
-                    time.sleep(0.05)
-
-                refresh = self.main_window.findChild(QAction, "actionRefreshTab")
-                refresh.trigger()
-
-        self.load_thread = WaitForBackendThread()
-        self.load_thread.start()
-        self.set_cursor_busy()
-
     def _open_no_backend_found(self, message_id):
         """
         No backends are present. Hide the sidebar and show a full screen message.
@@ -906,31 +795,18 @@ class DevicesTab(shared.TabData):
                 }
             ]
 
-        self.widgets.populate_empty_state(layout, image, title, desc, buttons)
-
-    def open_bad_device(self, msg1, msg2, exception):
-        """
-        Show a page to inform the user the device could not be opened. Possibly
-        due to a temporary glitch or unsupported feature.
-        """
-        layout = self.Contents.layout()
-        layout.setContentsMargins(0, 0, 0, 0)
-        shared.clear_layout(layout)
-
-        def _view_details():
-            _ = self._
-            self.widgets.open_dialog(self.widgets.dialog_generic, _("Error Details"), msg1, msg2, exception)
-
-        self.widgets.populate_empty_state(layout, common.get_icon("empty", "nobackend"), self._("There was a problem opening this device"), "",
-            [
+        if self.appdata.flatpak_mode:
+            # Troubleshooter not possible. Open OpenRazer wiki and remove our help button
+            buttons = [
                 {
-                    "label": self._("View Details"),
-                    "icon_folder": "emblems",
-                    "icon_name": "software",
-                    "action": _view_details
+                    "label": self._("Troubleshooting Guide"),
+                    "icon_folder": "general",
+                    "icon_name": "external",
+                    "action": self._start_troubleshooter
                 }
-            ])
-        self.set_cursor_normal()
+            ]
+
+        self.widgets.populate_empty_state(layout, image, title, desc, buttons)
 
     def open_apply_to_all(self):
         """
@@ -950,7 +826,7 @@ class DevicesTab(shared.TabData):
             button = QToolButton()
             button.setText(option.label)
             button.setIconSize(QSize(40, 40))
-            button.setToolButtonStyle(Qt.ToolButtonTextUnderIcon)
+            button.setToolButtonStyle(Qt.ToolButtonStyle.ToolButtonTextUnderIcon)
             button.setIcon(QIcon(option.icon))
             button.setMinimumHeight(70)
             button.setMinimumWidth(105)
@@ -1193,8 +1069,7 @@ class DevicesTab(shared.TabData):
         _ = self._
 
         # Dialog Controls
-        self.dialog = shared.get_ui_widget(self.appdata, "inspect-matrix", QDialog)
-        label = self.dialog.findChild(QLabel, "Label")
+        self.dialog: QDialog = shared.get_ui_widget(self.appdata, "inspect-matrix", QDialog)
         table = self.dialog.findChild(QTableWidget, "Matrix")
         btn_close = self.dialog.findChild(QPushButton, "Close")
         cur_pos = self.dialog.findChild(QLabel, "CurrentPosition")
@@ -1205,7 +1080,6 @@ class DevicesTab(shared.TabData):
 
         def _close_test():
             self.middleman.replay_active_effect(device)
-            self.dialog.accept()
 
         # Populate table
         for x in range(0, device.matrix.cols):
@@ -1236,13 +1110,14 @@ class DevicesTab(shared.TabData):
             device.matrix.draw()
 
         # Connect signals and set focus
-        btn_close.clicked.connect(_close_test)
+        btn_close.clicked.connect(self.dialog.accept)
         table.itemSelectionChanged.connect(_set_pos)
         table.setFocus()
         table.setCurrentCell(0, 0)
         self.dialog.adjustSize()
         self.dialog.resize(QSize(self.dialog.width() + 5, self.dialog.height()))
         self.dialog.setWindowTitle(self._("Inspect Matrix") + " - " + device.name)
+        self.dialog.finished.connect(_close_test)
         self.dialog.open()
 
 
@@ -1437,74 +1312,6 @@ class SpecialControls(shared.TabData):
 
         return self.widgets.create_row_widget(self._("DPI"), [stage_widget, dpi_widget], vertical=True)
 
-    def create_mouse_accel_control(self):
-        """
-        Creates a button that'll either:
-          - Open mouse acceleration settings for known desktop environments
-          - Or inform the user if desktop environment unknown.
-
-        Due to the diverse range of desktop environments, getting mouse
-        acceleration values isn't supported right now.
-        """
-        # TODO: Move to middleman to use for all mice
-        def _get_current_desktop_env():
-            try:
-                desktop_env = os.environ["XDG_CURRENT_DESKTOP"]
-
-                # Some distros add a prefix/suffix ("ubuntu", "X-")
-                if desktop_env.find("GNOME") != -1:
-                    return "GNOME"
-                elif desktop_env.find("Cinnamon") != -1:
-                    return "Cinnamon"
-                elif desktop_env in ["KDE", "MATE", "Pantheon", "LXQt"]:
-                    return desktop_env
-                return "Unknown"
-            except KeyError:
-                return "Unknown"
-
-        def _get_command():
-            desktop_env = _get_current_desktop_env()
-            desktop_to_cmd = {
-                "GNOME": "gnome-control-center mouse",
-                "Cinnamon": "cinnamon-settings mouse",
-                "KDE": "systemsettings5 mouse",
-                "MATE": "mate-mouse-properties",
-                "Pantheon": "io.elementary.switchboard settings://input/mouse",
-                "LXQt": "lxqt-config-input",
-            }
-            try:
-                return desktop_to_cmd[desktop_env]
-            except KeyError:
-                return None
-
-        def _open_mouse_settings():
-            command = _get_command()
-            if command:
-                self.dbg.stdout("Opening: " + command, self.dbg.action, 1)
-                subprocess.Popen(command.split(" "))
-                return
-
-            # Desktop environment unknown, inform the user for manual action.
-            self.widgets.open_dialog(self.widgets.dialog_generic,
-                                     self._("Mouse Acceleration"),
-                                     self._("This feature is provided by your operating system. Polychromatic doesn't recognise this desktop environment " + \
-                                            "to automatically open the settings window for you.\n\n" + \
-                                            "Look for 'mouse', 'input' or 'hardware' in your System Settings."))
-
-        widget = QWidget()
-        layout = QHBoxLayout()
-        layout.setContentsMargins(0, 0, 0, 0)
-        widget.setLayout(layout)
-        button = QPushButton()
-        button.setText(self._("Open Mouse Settings"))
-        button.setIconSize(QSize(24, 24))
-        button.setIcon(QIcon.fromTheme("input-mouse"))
-        button.clicked.connect(_open_mouse_settings)
-        layout.addWidget(button)
-        layout.addStretch()
-
-        return self.widgets.create_row_widget(self._("Acceleration"), [widget])
-
     def create_programmable_keys_control(self, path):
         """
         Returns a widget that informs the user that this software does not
@@ -1518,7 +1325,7 @@ class SpecialControls(shared.TabData):
         button.clicked.connect(_open_input_remapper)
 
         spacer = QWidget()
-        spacer.setSizePolicy(QSizePolicy.MinimumExpanding, QSizePolicy.Preferred)
+        spacer.setSizePolicy(QSizePolicy.Policy.MinimumExpanding, QSizePolicy.Policy.Preferred)
 
         return self.widgets.create_row_widget("", [button, spacer])
 
@@ -1542,7 +1349,7 @@ class SpecialControls(shared.TabData):
         button.clicked.connect(_open_macro_dialog)
 
         spacer = QWidget()
-        spacer.setSizePolicy(QSizePolicy.MinimumExpanding, QSizePolicy.Preferred)
+        spacer.setSizePolicy(QSizePolicy.Policy.MinimumExpanding, QSizePolicy.Policy.Preferred)
 
         return self.widgets.create_row_widget(self._("Macros"), [button, spacer])
 
@@ -1576,7 +1383,7 @@ class DPIStageEditor(shared.TabData):
         self.btn_stage_add = self.dialog.findChild(QPushButton, "StageAdd")
         self.btn_stage_del = self.dialog.findChild(QPushButton, "StageDel")
         self.dialog_buttons = self.dialog.findChild(QDialogButtonBox, "buttonBox")
-        self.btn_save = self.dialog_buttons.button(QDialogButtonBox.Save)
+        self.btn_save = self.dialog_buttons.button(QDialogButtonBox.StandardButton.Save)
 
         # Set icons for controls
         if not self.appdata.system_qt_theme:
