@@ -4,23 +4,15 @@
 This module controls the 'Effects' tab of the Controller GUI.
 """
 
-from .. import common
-from .. import effects
-from .. import locales
-from .. import procpid
-from .. import preferences as pref
-from . import shared
-from . import editor
 
-import os
+from PyQt6.QtCore import Qt
+from PyQt6.QtGui import QIcon
+from PyQt6.QtWidgets import (QComboBox, QDialog, QDialogButtonBox, QGroupBox,
+                             QLabel, QLineEdit, QMessageBox, QPushButton,
+                             QRadioButton, QSizePolicy, QTextEdit, QToolButton)
 
-from PyQt5.QtCore import Qt
-from PyQt5.QtGui import QIcon, QPixmap
-from PyQt5.QtWidgets import QWidget, QPushButton, QToolButton, QMessageBox, \
-                            QListWidget, QTreeWidget, QLabel, QComboBox, \
-                            QTreeWidgetItem, QMenu, QDialog, QDialogButtonBox, \
-                            QButtonGroup, QLineEdit, QTextEdit, QCheckBox, \
-                            QGroupBox, QRadioButton, QMainWindow
+from .. import common, effects, procpid
+from . import editor, shared
 
 
 class EffectsTab(shared.CommonFileTab):
@@ -202,38 +194,6 @@ class EffectsTab(shared.CommonFileTab):
             self.set_tab()
             self.open_file(path)
 
-        # Backends not ready - cannot show device list
-        if not self.appdata.ready:
-            self.dbg.stdout("Backends not ready! Device list will not be available for new effect.", self.dbg.warning, 1)
-            action = ""
-
-            def do_ignore():
-                # Let the metadata editor handle no devices
-                pass
-
-            def do_retry():
-                nonlocal action
-                action = "retry"
-
-            def do_cancel():
-                nonlocal action
-                action = "cancel"
-
-            self.widgets.open_dialog(self.widgets.dialog_warning,
-                                     self._("Backend Not Ready"),
-                                     self._("The application is still waiting for the backends to finish initialising so you can pick a device to map your new effect."),
-                                     info_text=self._("This might be ready in a few moments."),
-                                     buttons=[QMessageBox.Ignore, QMessageBox.Retry],
-                                     actions={
-                                         QMessageBox.Ignore: do_ignore,
-                                         QMessageBox.Retry: do_retry
-                                     })
-
-            if action == "cancel":
-                return
-            elif action == "retry":
-                return self.new_file_stage_2(old_dialog, effect_type)
-
         metadata_editor = EffectMetadataEditor(self.appdata, data, _save_metadata)
 
     def open_file(self, effect_path):
@@ -325,6 +285,8 @@ class EffectsTab(shared.CommonFileTab):
             summary_label = QLabel()
             summary_label.setText(summary_text)
             summary_label.setWordWrap(True)
+            summary_label.setSizePolicy(QSizePolicy.Policy.Expanding, QSizePolicy.Policy.Preferred)
+            summary_label.setAlignment(Qt.AlignmentFlag.AlignTop)
             layout.addWidget(self.widgets.create_row_widget(self._("Summary"), [summary_label]))
 
         # Show other actions for this effect
@@ -380,7 +342,6 @@ class EffectsTab(shared.CommonFileTab):
         Allows the user to create effects from other media, such as videos or images.
         """
         print("stub:effects.import_effect")
-        pass
 
     def play_effect(self, device_name=None):
         """
@@ -563,7 +524,7 @@ class EffectMetadataEditor(shared.TabData):
             len(self.name.text()) > 0
         ]
 
-        self.buttons.button(QDialogButtonBox.Ok).setEnabled(all(x is True for x in conditions))
+        self.buttons.button(QDialogButtonBox.StandardButton.Ok).setEnabled(all(x is True for x in conditions))
 
     def _device_updated(self):
         """
